@@ -17,7 +17,6 @@
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
-import logging
 import sys
 if sys.version_info[:2] <= (2, 6):
 	from ordereddict import OrderedDict
@@ -27,8 +26,7 @@ else:
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
-import foundations.core as core
-from foundations.globals.constants import Constants
+import foundations.verbose
 
 #**********************************************************************************************************************
 #***	Module attributes.
@@ -46,7 +44,7 @@ __all__ = ["LOGGER",
 			"OrderedStructure",
 			"Lookup"]
 
-LOGGER = logging.getLogger(Constants.logger)
+LOGGER = foundations.verbose.installLogger()
 
 #**********************************************************************************************************************
 #***	Module classes and definitions.
@@ -66,7 +64,6 @@ class NestedAttribute(object):
 		64
 	"""
 
-	# @core.executionTrace
 	def __getattr__(self, attribute):
 		"""
 		This method returns requested attribute.
@@ -78,7 +75,6 @@ class NestedAttribute(object):
 		self.__dict__[attribute] = NestedAttribute()
 		return self.__dict__[attribute]
 
-	# @core.executionTrace
 	def __setattr__(self, attribute, value):
 		"""
 		This method sets given attribute with given value.
@@ -90,7 +86,6 @@ class NestedAttribute(object):
 		namespaces = attribute.split(".")
 		object.__setattr__(reduce(object.__getattribute__, namespaces[:-1], self), namespaces[-1], value)
 
-	# @core.executionTrace
 	def __delattr__(self, attribute):
 		"""
 		This method deletes given attribute with.
@@ -125,7 +120,6 @@ class Structure(dict):
 		AttributeError: 'Structure' object has no attribute 'gender'
 	"""
 
-	@core.executionTrace
 	def __init__(self, *args, **kwargs):
 		"""
 		This method initializes the class.
@@ -137,7 +131,6 @@ class Structure(dict):
 		dict.__init__(self, **kwargs)
 		self.__dict__.update(**kwargs)
 
-	# @core.executionTrace
 	def __getattr__(self, attribute):
 		"""
 		This method returns given attribute value.
@@ -150,13 +143,12 @@ class Structure(dict):
 		except KeyError:
 			raise AttributeError("'{0}' object has no attribute '{1}'".format(self.__class__.__name__, attribute))
 
-	# @core.executionTrace
 	def __setattr__(self, attribute, value):
 		"""
 		This method sets both key and sibling attribute with given value.
 
-		:param attribute.: Attribute. ( Object )
-		:param value.: Value. ( Object )
+		:param attribute: Attribute. ( Object )
+		:param value: Value. ( Object )
 		"""
 
 		dict.__setitem__(self, attribute, value)
@@ -164,12 +156,11 @@ class Structure(dict):
 
 	__setitem__ = __setattr__
 
-	# @core.executionTrace
 	def __delattr__(self, attribute):
 		"""
 		This method deletes both key and sibling attribute.
 
-		:param attribute.: Attribute. ( Object )
+		:param attribute: Attribute. ( Object )
 		"""
 
 		dict.__delitem__(self, attribute)
@@ -177,7 +168,6 @@ class Structure(dict):
 
 	__delitem__ = __delattr__
 
-	# @core.executionTrace
 	def update(self, *args, **kwargs):
 		"""
 		This method reimplements the :meth:`Dict.update` method.
@@ -220,7 +210,6 @@ class OrderedStructure(OrderedDict):
 		'Kate'
 	"""
 
-	@core.executionTrace
 	def __init__(self, *args, **kwargs):
 		"""
 		This method initializes the class.
@@ -231,13 +220,12 @@ class OrderedStructure(OrderedDict):
 
 		OrderedDict.__init__(self, *args, **kwargs)
 
-	# @core.executionTrace
 	def __setitem__(self, key, value, *args, **kwargs):
 		"""
 		This method sets a key and sibling attribute with given value.
 
-		:param key.: Key. ( Object )
-		:param value.: Value. ( Object )
+		:param key: Key. ( Object )
+		:param value: Value. ( Object )
 		:param \*args: Arguments. ( \* )
 		:param \*\*kwargs: Key / Value pairs. ( Key / Value pairs )
 		"""
@@ -245,12 +233,11 @@ class OrderedStructure(OrderedDict):
 		OrderedDict.__setitem__(self, key, value, *args, **kwargs)
 		OrderedDict.__setattr__(self, key, value)
 
-	# @core.executionTrace
 	def __delitem__(self, key, *args, **kwargs):
 		"""
 		This method deletes both key and sibling attribute.
 
-		:param key.: Key. ( Object )
+		:param key: Key. ( Object )
 		:param \*args: Arguments. ( \* )
 		:param \*\*kwargs: Key / Value pairs. ( Key / Value pairs )
 		"""
@@ -258,13 +245,12 @@ class OrderedStructure(OrderedDict):
 		OrderedDict.__delitem__(self, key, *args, **kwargs)
 		OrderedDict.__delattr__(self, key)
 
-	# @core.executionTrace
 	def __setattr__(self, attribute, value):
 		"""
 		This method sets both key and sibling attribute with given value.
 
-		:param attribute.: Attribute. ( Object )
-		:param value.: Value. ( Object )
+		:param attribute: Attribute. ( Object )
+		:param value: Value. ( Object )
 		"""
 
 		if sys.version_info[:2] <= (2, 6):
@@ -276,12 +262,11 @@ class OrderedStructure(OrderedDict):
 					OrderedDict.__setitem__(self, attribute, value)
 		OrderedDict.__setattr__(self, attribute, value)
 
-	# @core.executionTrace
 	def __delattr__(self, attribute):
 		"""
 		This method deletes both key and sibling attribute.
 
-		:param attribute.: Attribute. ( Object )
+		:param attribute: Attribute. ( Object )
 		"""
 
 		if sys.version_info[:2] <= (2, 6):
@@ -302,17 +287,16 @@ class Lookup(dict):
 		>>> person = Lookup(firstName="Doe", lastName="John", gender="male")
 		>>> person.getFirstKeyFromValue("Doe")
 		'firstName'
-		>>> persons = foundations.foundations.dataStructures.Lookup(John="Doe", Jane="Doe", Luke="Skywalker")
+		>>> persons = foundations.dataStructures.Lookup(John="Doe", Jane="Doe", Luke="Skywalker")
 		>>> persons.getKeysFromValue("Doe")
 		['Jane', 'John']
 	"""
 
-	# @core.executionTrace
 	def getFirstKeyFromValue(self, value):
 		"""
 		This method gets the first key from given value.
 
-		:param value.: Value. ( Object )
+		:param value: Value. ( Object )
 		:return: Key. ( Object )
 		"""
 
@@ -320,12 +304,11 @@ class Lookup(dict):
 			if data == value:
 				return key
 
-	# @core.executionTrace
 	def getKeysFromValue(self, value):
 		"""
 		This method gets the keys from given value.
 
-		:param value.: Value. ( Object )
+		:param value: Value. ( Object )
 		:return: Keys. ( Object )
 		"""
 
