@@ -20,7 +20,6 @@
 #**********************************************************************************************************************
 import base64
 import datetime
-import logging
 import re
 import sys
 from xml.etree import ElementTree
@@ -33,14 +32,13 @@ else:
 #***	Internal imports.
 #**********************************************************************************************************************
 import foundations.common
-import foundations.core as core
 import foundations.dataStructures
 import foundations.exceptions
-import foundations.io as io
-import foundations.namespace as namespace
-import foundations.strings as strings
+import foundations.io
+import foundations.namespace
+import foundations.strings
+import foundations.verbose
 import foundations.walkers
-from foundations.globals.constants import Constants
 
 #**********************************************************************************************************************
 #***	Module attributes.
@@ -54,7 +52,7 @@ __status__ = "Production"
 
 __all__ = ["LOGGER", "AttributeCompound", "SectionsFileParser", "PlistFileParser", "getAttributeCompound"]
 
-LOGGER = logging.getLogger(Constants.logger)
+LOGGER = foundations.verbose.installLogger()
 
 #**********************************************************************************************************************
 #***	Module classes and definitions.
@@ -72,7 +70,6 @@ class AttributeCompound(foundations.dataStructures.Structure):
 
 	"""
 
-	@core.executionTrace
 	def __init__(self, **kwargs):
 		"""
 		This method initializes the class.
@@ -92,7 +89,7 @@ class AttributeCompound(foundations.dataStructures.Structure):
 
 		foundations.dataStructures.Structure.__init__(self, **kwargs)
 
-class SectionsFileParser(io.File):
+class SectionsFileParser(foundations.io.File):
 	"""
 	This class provides methods to parse sections file format files,
 	an alternative configuration file parser is available directly with Python: :class:`ConfigParser.ConfigParser`.
@@ -112,7 +109,6 @@ class SectionsFileParser(io.File):
 
 	"""
 
-	@core.executionTrace
 	def __init__(self,
 				file=None,
 				splitters=("=", ":"),
@@ -150,7 +146,7 @@ class SectionsFileParser(io.File):
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		io.File.__init__(self, file)
+		foundations.io.File.__init__(self, file)
 
 		# --- Setting class attributes. ---
 		self.__splitters = None
@@ -186,7 +182,7 @@ class SectionsFileParser(io.File):
 		return self.__splitters
 
 	@splitters.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def splitters(self, value):
 		"""
 		This method is the setter method for **self.__splitters** attribute.
@@ -206,7 +202,7 @@ class SectionsFileParser(io.File):
 		self.__splitters = value
 
 	@splitters.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def splitters(self):
 		"""
 		This method is the deleter method for **self.__splitters** attribute.
@@ -226,7 +222,7 @@ class SectionsFileParser(io.File):
 		return self.__namespaceSplitter
 
 	@namespaceSplitter.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def namespaceSplitter(self, value):
 		"""
 		This method is the setter method for **self.__namespaceSplitter** attribute.
@@ -243,7 +239,7 @@ class SectionsFileParser(io.File):
 		self.__namespaceSplitter = value
 
 	@namespaceSplitter.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def namespaceSplitter(self):
 		"""
 		This method is the deleter method for **self.__namespaceSplitter** attribute.
@@ -263,7 +259,7 @@ class SectionsFileParser(io.File):
 		return self.__commentLimiters
 
 	@commentLimiters.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def commentLimiters(self, value):
 		"""
 		This method is the setter method for **self.__commentLimiters** attribute.
@@ -280,7 +276,7 @@ class SectionsFileParser(io.File):
 		self.__commentLimiters = value
 
 	@commentLimiters.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def commentLimiters(self):
 		"""
 		This method is the deleter method for **self.__commentLimiters** attribute.
@@ -300,7 +296,7 @@ class SectionsFileParser(io.File):
 		return self.__commentMarker
 
 	@commentMarker.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def commentMarker(self, value):
 		"""
 		This method is the setter method for **self.__commentMarker** attribute.
@@ -316,7 +312,7 @@ class SectionsFileParser(io.File):
 		self.__commentMarker = value
 
 	@commentMarker.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def commentMarker(self):
 		"""
 		This method is the deleter method for **self.__commentMarker** attribute.
@@ -336,7 +332,7 @@ class SectionsFileParser(io.File):
 		return self.__quotationMarkers
 
 	@quotationMarkers.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def quotationMarkers(self, value):
 		"""
 		This method is the setter method for **self.__quotationMarkers** attribute.
@@ -357,7 +353,7 @@ class SectionsFileParser(io.File):
 		self.__quotationMarkers = value
 
 	@quotationMarkers.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def quotationMarkers(self):
 		"""
 		This method is the deleter method for **self.__quotationMarkers** attribute.
@@ -377,7 +373,7 @@ class SectionsFileParser(io.File):
 		return self.__rawSectionContentIdentifier
 
 	@rawSectionContentIdentifier.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def rawSectionContentIdentifier(self, value):
 		"""
 		This method is the setter method for **self.__rawSectionContentIdentifier** attribute.
@@ -391,7 +387,7 @@ class SectionsFileParser(io.File):
 		self.__rawSectionContentIdentifier = value
 
 	@rawSectionContentIdentifier.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def rawSectionContentIdentifier(self):
 		"""
 		This method is the deleter method for **self.__rawSectionContentIdentifier** attribute.
@@ -411,7 +407,7 @@ class SectionsFileParser(io.File):
 		return self.__defaultsSection
 
 	@defaultsSection.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def defaultsSection(self, value):
 		"""
 		This method is the setter method for **self.__defaultsSection** attribute.
@@ -425,7 +421,7 @@ class SectionsFileParser(io.File):
 		self.__defaultsSection = value
 
 	@defaultsSection.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def defaultsSection(self):
 		"""
 		This method is the deleter method for **self.__defaultsSection** attribute.
@@ -445,7 +441,7 @@ class SectionsFileParser(io.File):
 		return self.__sections
 
 	@sections.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def sections(self, value):
 		"""
 		This method is the setter method for **self.__sections** attribute.
@@ -464,7 +460,7 @@ class SectionsFileParser(io.File):
 		self.__sections = value
 
 	@sections.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def sections(self):
 		"""
 		This method is the deleter method for **self.__sections** attribute.
@@ -484,7 +480,7 @@ class SectionsFileParser(io.File):
 		return self.__comments
 
 	@comments.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def comments(self, value):
 		"""
 		This method is the setter method for **self.__comments** attribute.
@@ -503,7 +499,7 @@ class SectionsFileParser(io.File):
 		self.__comments = value
 
 	@comments.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def comments(self):
 		"""
 		This method is the deleter method for **self.__comments** attribute.
@@ -523,7 +519,7 @@ class SectionsFileParser(io.File):
 		return self.__parsingErrors
 
 	@parsingErrors.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def parsingErrors(self, value):
 		"""
 		This method is the setter method for **self.__parsingErrors** attribute.
@@ -540,7 +536,7 @@ class SectionsFileParser(io.File):
 		self.__parsingErrors = value
 
 	@parsingErrors.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def parsingErrors(self):
 		"""
 		This method is the deleter method for **self.__parsingErrors** attribute.
@@ -552,8 +548,7 @@ class SectionsFileParser(io.File):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.FileStructureParsingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.FileStructureParsingError)
 	def parse(self,
 			orderedDictionary=True,
 			rawSections=None,
@@ -601,7 +596,7 @@ class SectionsFileParser(io.File):
 		:return: Method success. ( Boolean )
 		"""
 
-		LOGGER.debug("> Reading sections from: '{0}'.".format(self.file))
+		LOGGER.debug("> Reading sections from: '{0}'.".format(self.path))
 
 		if not self.content:
 			return False
@@ -668,16 +663,14 @@ class SectionsFileParser(io.File):
 			self.__sections[section] = attributes
 
 		LOGGER.debug("> Sections: '{0}'.".format(self.__sections))
-		LOGGER.debug("> '{0}' file parsing done!".format(self.file))
+		LOGGER.debug("> '{0}' file parsing done!".format(self.path))
 
 		if self.__parsingErrors and raiseParsingErrors:
 			raise foundations.exceptions.FileStructureParsingError(
-			"{0} | '{1}' structure is invalid, parsing exceptions occured!".format(self.__class__.__name__, self.file))
+			"{0} | '{1}' structure is invalid, parsing exceptions occured!".format(self.__class__.__name__, self.path))
 
 		return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def sectionExists(self, section):
 		"""
 		This method checks if given section exists.
@@ -709,8 +702,6 @@ class SectionsFileParser(io.File):
 			LOGGER.debug("> '{0}' section doesn't exists in '{1}'.".format(section, self))
 			return False
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, KeyError)
 	def attributeExists(self, attribute, section):
 		"""
 		This method checks if given attribute exists.
@@ -736,7 +727,7 @@ class SectionsFileParser(io.File):
 		if not self.__sections:
 			return False
 
-		if namespace.removeNamespace(attribute, rootOnly=True) in self.getAttributes(section,
+		if foundations.namespace.removeNamespace(attribute, rootOnly=True) in self.getAttributes(section,
 																					orderedDictionary=True,
 																					stripNamespaces=True):
 			LOGGER.debug("> '{0}' attribute exists in '{1}' section.".format(attribute, section))
@@ -745,9 +736,7 @@ class SectionsFileParser(io.File):
 			LOGGER.debug("> '{0}' attribute doesn't exists in '{1}' section.".format(attribute, section))
 			return False
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, KeyError)
-	def getAttributes(self, section, orderedDictionary=True, stripNamespaces=False, raiseExceptions=True):
+	def getAttributes(self, section, orderedDictionary=True, stripNamespaces=False):
 		"""
 		This method returns given section attributes.
 
@@ -769,33 +758,23 @@ class SectionsFileParser(io.File):
 		:param section: Section containing the requested attributes. ( String )
 		:param orderedDictionary: Use an :class:`collections.OrderedDict` dictionary to store the attributes. ( String )
 		:param stripNamespaces: Strip namespaces while retrieving attributes. ( Boolean )
-		:param raiseExceptions: Raise if section doesn't exists. ( Boolean )
 		:return: Attributes. ( OrderedDict / Dictionary )
 		"""
 
 		LOGGER.debug("> Getting section '{0}' attributes.".format(section))
-		if self.sectionExists(section):
-			dictionary = orderedDictionary and OrderedDict or dict
-			attributes = dictionary()
-			if stripNamespaces:
-				for attribute, value in self.__sections[section].iteritems():
-					attributes[namespace.removeNamespace(attribute, rootOnly=True)] = value
-			else:
-				attributes.update(self.__sections[section])
-			LOGGER.debug("> Attributes: '{0}'.".format(attributes))
+		dictionary = orderedDictionary and OrderedDict or dict
+		attributes = dictionary()
+		if not self.sectionExists(section):
 			return attributes
-		else:
-			if raiseExceptions:
-				raise KeyError("{0} | '{1}' section doesn't exists in '{2}' sections!".format(self.__class__.__name__,
-																							section,
-																							self.file))
-			else:
-				LOGGER.warning("!> {0} | '{1}' section doesn't exists in '{2}' sections!".format(self.__class__.__name__,
-																								section,
-																								self.file))
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
+		if stripNamespaces:
+			for attribute, value in self.__sections[section].iteritems():
+				attributes[foundations.namespace.removeNamespace(attribute, rootOnly=True)] = value
+		else:
+			attributes.update(self.__sections[section])
+		LOGGER.debug("> Attributes: '{0}'.".format(attributes))
+		return attributes
+
 	def getAllAttributes(self, orderedDictionary=True):
 		"""
 		This method returns all sections attributes.
@@ -827,9 +806,7 @@ class SectionsFileParser(io.File):
 				allAttributes[attribute] = value
 		return allAttributes
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, KeyError)
-	def getValue(self, attribute, section, encode=False):
+	def getValue(self, attribute, section, encode=False, default=str()):
 		"""
 		This method returns requested attribute value.
 
@@ -847,23 +824,24 @@ class SectionsFileParser(io.File):
 		:param attribute: Attribute name. ( String )
 		:param section: Section containing the searched attribute. ( String )
 		:param encode: Encode value to unicode. ( Boolean )
+		:param default: Default return value. ( Object )
 		:return: Attribute value. ( String )
 		"""
 
 		if not self.__sections:
-			return str()
+			return default
 
-		if self.attributeExists(attribute, section):
-			if attribute in self.__sections[section]:
-				value = self.__sections[section][attribute]
-			elif namespace.setNamespace(section, attribute) in self.__sections[section]:
-				value = self.__sections[section][namespace.setNamespace(section, attribute)]
-			LOGGER.debug("> Attribute: '{0}', value: '{1}'.".format(attribute, value))
-			value = encode and strings.encode(value) or value
-			return value
+		if not self.attributeExists(attribute, section):
+			return default
+
+		if attribute in self.__sections[section]:
+			value = self.__sections[section][attribute]
+		elif foundations.namespace.setNamespace(section, attribute) in self.__sections[section]:
+			value = self.__sections[section][foundations.namespace.setNamespace(section, attribute)]
+		LOGGER.debug("> Attribute: '{0}', value: '{1}'.".format(attribute, value))
+		value = foundations.strings.encode(value) if encode else value
+		return value
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def write(self,
 			namespaces=False,
 			splitter="=",
@@ -898,10 +876,10 @@ class SectionsFileParser(io.File):
 		if not self.__sections:
 			return False
 
-		LOGGER.debug("> Setting '{0}' file content.".format(self.file))
+		LOGGER.debug("> Setting '{0}' file content.".format(self.path))
 		attributeTemplate = spacesAroundSplitter and "{{0}} {0} {{1}}\n".format(splitter) or \
 							"{{0}} {0} {{1}}\n".format(splitter)
-		attributeTemplate = strings.replace(attributeTemplate, {"{{" : "{", "}}" : "}"})
+		attributeTemplate = foundations.strings.replace(attributeTemplate, {"{{" : "{", "}}" : "}"})
 		commentTemplate = spaceAfterCommentLimiter and "{0} {{0}}\n".format(commentLimiter) or \
 							"{0}{{0}}\n".format(commentLimiter)
 		if self.__defaultsSection in self.__sections:
@@ -945,15 +923,14 @@ class SectionsFileParser(io.File):
 					self.content.append(attributeTemplate.format(attribute, value))
 			if i != len(self.__sections) - 1:
 				self.content.append("\n")
-		io.File.write(self)
+		foundations.io.File.write(self)
 		return True
 
-class PlistFileParser(io.File):
+class PlistFileParser(foundations.io.File):
 	"""
 	This class provides methods to parse plist files.
 	"""
 
-	@core.executionTrace
 	def __init__(self, file=None):
 		"""
 		This method initializes the class.
@@ -973,7 +950,7 @@ class PlistFileParser(io.File):
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		io.File.__init__(self, file)
+		foundations.io.File.__init__(self, file)
 
 		# --- Setting class attributes. ---
 		self.__elements = None
@@ -1004,7 +981,7 @@ class PlistFileParser(io.File):
 		return self.__elements
 
 	@elements.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def elements(self, value):
 		"""
 		This method is the setter method for **self.__elements** attribute.
@@ -1017,7 +994,7 @@ class PlistFileParser(io.File):
 		self.__elements = value
 
 	@elements.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def elements(self):
 		"""
 		This method is the deleter method for **self.__elements** attribute.
@@ -1037,7 +1014,7 @@ class PlistFileParser(io.File):
 		return self.__parsingErrors
 
 	@parsingErrors.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def parsingErrors(self, value):
 		"""
 		This method is the setter method for **self.__parsingErrors** attribute.
@@ -1054,7 +1031,7 @@ class PlistFileParser(io.File):
 		self.__parsingErrors = value
 
 	@parsingErrors.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def parsingErrors(self):
 		"""
 		This method is the deleter method for **self.__parsingErrors** attribute.
@@ -1074,7 +1051,7 @@ class PlistFileParser(io.File):
 		return self.__unserializers
 
 	@unserializers.setter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def unserializers(self, value):
 		"""
 		This method is the setter method for **self.__unserializers** attribute.
@@ -1086,7 +1063,7 @@ class PlistFileParser(io.File):
 		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "unserializers"))
 
 	@unserializers.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def unserializers(self):
 		"""
 		This method is the deleter method for **self.__unserializers** attribute.
@@ -1098,8 +1075,7 @@ class PlistFileParser(io.File):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.FileStructureParsingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.FileStructureParsingError)
 	def parse(self, raiseParsingErrors=True):
 		"""
 		This method process the file content.
@@ -1116,9 +1092,9 @@ class PlistFileParser(io.File):
 		:return: Method success. ( Boolean )
 		"""
 
-		LOGGER.debug("> Reading elements from: '{0}'.".format(self.file))
+		LOGGER.debug("> Reading elements from: '{0}'.".format(self.path))
 
-		elementTreeParser = ElementTree.iterparse(self.file)
+		elementTreeParser = ElementTree.iterparse(self.path)
 
 		self.__parsingErrors = []
 		for action, element in elementTreeParser:
@@ -1134,13 +1110,11 @@ class PlistFileParser(io.File):
 		if self.__parsingErrors:
 			if raiseParsingErrors:
 				raise foundations.exceptions.FileStructureParsingError(
-				"{0} | '{1}' structure is invalid, parsing exceptions occured!".format(self.__class__.__name__, self.file))
+				"{0} | '{1}' structure is invalid, parsing exceptions occured!".format(self.__class__.__name__, self.path))
 		else:
 			self.__elements = foundations.common.getFirstItem(elementTreeParser.root).text
 			return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, KeyError)
 	def elementExists(self, element):
 		"""
 		This method checks if given element exists.
@@ -1171,8 +1145,6 @@ class PlistFileParser(io.File):
 		LOGGER.debug("> '{0}' element doesn't exists.".format(element))
 		return False
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def filterValues(self, pattern, flags=0):
 		"""
 		| This method filters the :meth:`PlistFileParser.elements` class property elements using given pattern.
@@ -1204,7 +1176,6 @@ class PlistFileParser(io.File):
 				values.append(value)
 		return values
 
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def getValue(self, element):
 		"""
 		| This method returns the given element value.
@@ -1228,8 +1199,6 @@ class PlistFileParser(io.File):
 		values = self.filterValues(r"^{0}$".format(element))
 		return foundations.common.getFirstItem(values)
 
-@core.executionTrace
-@foundations.exceptions.exceptionsHandler(None, False, Exception)
 def getAttributeCompound(attribute, value=None, splitter="|", bindingIdentifier="@"):
 	"""
 	This definition returns an attribute compound.
