@@ -63,8 +63,6 @@ class ConstantsTestCase(unittest.TestCase):
 								"verbosityLabels",
 								"loggingDefaultFormatter",
 								"loggingSeparators",
-								"executionTraceArgumentMaximumLength",
-								"excludeTaggedFramesFromStackTrace",
 								"encodingFormat",
 								"encodingError",
 								"applicationDirectory",
@@ -148,20 +146,6 @@ class ConstantsTestCase(unittest.TestCase):
 
 		self.assertIsInstance(Constants.loggingSeparators, str)
 
-	def testExecutionTraceArgumentMaximumLengthAttribute(self):
-		"""
-		This method tests :attr:`foundations.globals.constants.Constants.executionTraceArgumentMaximumLength` attribute.
-		"""
-
-		self.assertIsInstance(Constants.executionTraceArgumentMaximumLength, int)
-
-	def testExcludeTaggedFramesFromStackTraceAttribute(self):
-		"""
-		This method tests :attr:`foundations.globals.constants.Constants.excludeTaggedFramesFromStackTrace` attribute.
-		"""
-
-		self.assertIsInstance(Constants.excludeTaggedFramesFromStackTrace, bool)
-
 	def testEncodingFormatAttribute(self):
 		"""
 		This method tests :attr:`foundations.globals.constants.Constants.encodingFormat` attribute.
