@@ -31,7 +31,7 @@ else:
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
-import foundations.namespace as namespace
+import foundations.namespace
 import foundations.parsers
 import foundations.walkers
 from foundations.parsers import PlistFileParser
@@ -312,8 +312,8 @@ PARSING_ERRORS_LINES_AND_VALUES = {3 : "Attribute structure is invalid: {0}".for
 									12 : "Attribute structure is invalid: {0}".format(
 										"This statement will produce the line nº '12' parsing error.\n")}
 
-RANDOM_ATTRIBUTES = {"component" : {"Component|Name" : "core.db",
-									"Component|Module" : "db",
+RANDOM_ATTRIBUTES = {"component" : {"Component|Name" : "core.database",
+									"Component|Module" : "database",
 									"Informations|Author" : "Thomas Mansencal",
 									"Informations|Email" : "thomas.mansencal@gmail.com"},
 					"iblSet" : {"Header|ICOfile" : "Icon.jpg",
@@ -351,7 +351,7 @@ RANDOM_COMMENTS = {"component" : {"Component|#0" : {"content" : "Component comme
 								"sIBL File Attributes|#1" : {"content" :
 														"sIBL File Attributes comment for tests purpose.", "id" : 1}}}
 
-SCRIPT_RAW_SECTION = [ "// @OutputScript - @Release for @Software @Version\n",
+SCRIPT_RAW_SECTION = ["// @OutputScript - @Release for @Software @Version\n",
 						"// Author: @Author\n",
 						"// EMail: @Email\n",
 						"// Homepage: @Url\n",
@@ -383,18 +383,18 @@ class SectionsFileParserTestCase(unittest.TestCase):
 		This method tests presence of required attributes.
 		"""
 
-		requiredAttributes = ("file",
-								"content",
-								"splitters",
-								"namespaceSplitter",
-								"commentLimiters",
-								"commentMarker",
-								"quotationMarkers",
-								"rawSectionContentIdentifier",
-								"defaultsSection",
-								"sections",
-								"comments",
-								"parsingErrors")
+		requiredAttributes = ("path",
+							"content",
+							"splitters",
+							"namespaceSplitter",
+							"commentLimiters",
+							"commentMarker",
+							"quotationMarkers",
+							"rawSectionContentIdentifier",
+							"defaultsSection",
+							"sections",
+							"comments",
+							"parsingErrors")
 
 		for attribute in requiredAttributes:
 			self.assertIn(attribute, dir(SectionsFileParser))
@@ -405,12 +405,12 @@ class SectionsFileParserTestCase(unittest.TestCase):
 		"""
 
 		requiredMethods = ("parse",
-							"sectionExists",
-							"attributeExists",
-							"getAttributes",
-							"getAllAttributes",
-							"getValue",
-							"write")
+						"sectionExists",
+						"attributeExists",
+						"getAttributes",
+						"getAllAttributes",
+						"getValue",
+						"write")
 
 		for method in requiredMethods:
 			self.assertIn(method, dir(SectionsFileParser))
@@ -548,9 +548,9 @@ class SectionsFileParserTestCase(unittest.TestCase):
 			sectionsFileParser = SectionsFileParser(file)
 			sectionsFileParser.read() and sectionsFileParser.parse(False, rawSections=STANDARD_FILES_RAW_SECTIONS[type])
 			for attribute in RANDOM_ATTRIBUTES[type]:
-				self.assertTrue(sectionsFileParser.attributeExists(attribute, namespace.getNamespace(attribute,
+				self.assertTrue(sectionsFileParser.attributeExists(attribute, foundations.namespace.getNamespace(attribute,
 																									rootOnly=True)))
-				self.assertFalse(sectionsFileParser.attributeExists("Unknown", namespace.getNamespace(attribute,
+				self.assertFalse(sectionsFileParser.attributeExists("Unknown", foundations.namespace.getNamespace(attribute,
 																									rootOnly=True)))
 
 	def testGetAttributes(self):
@@ -591,13 +591,15 @@ class SectionsFileParserTestCase(unittest.TestCase):
 			sectionsFileParser = SectionsFileParser(file)
 			sectionsFileParser.read() and sectionsFileParser.parse(False, rawSections=STANDARD_FILES_RAW_SECTIONS[type])
 			for attribute, value in RANDOM_ATTRIBUTES[type].iteritems():
-				self.assertIsInstance(sectionsFileParser.getValue(attribute, namespace.getNamespace(attribute,
+				self.assertIsInstance(sectionsFileParser.getValue(attribute, foundations.namespace.getNamespace(attribute,
 																									rootOnly=True)), str)
-				self.assertIsInstance(sectionsFileParser.getValue(attribute, namespace.getNamespace(attribute,
+				self.assertIsInstance(sectionsFileParser.getValue(attribute, foundations.namespace.getNamespace(attribute,
 																									rootOnly=True),
 																									encode=True), unicode)
-				self.assertEqual(sectionsFileParser.getValue(attribute, namespace.getNamespace(attribute,
+				self.assertEqual(sectionsFileParser.getValue(attribute, foundations.namespace.getNamespace(attribute,
 																								rootOnly=True)), value)
+			self.assertEqual(sectionsFileParser.getValue("attribute", "section", default=None), None)
+			self.assertEqual(sectionsFileParser.getValue("attribute", "section", default=list()), list())
 
 	def testWrite(self):
 		"""
@@ -610,16 +612,17 @@ class SectionsFileParserTestCase(unittest.TestCase):
 			readSectionsFileParser.read() and \
 			readSectionsFileParser.parse(stripComments=False, rawSections=STANDARD_FILES_RAW_SECTIONS[type])
 
-			writeSectionsFileParser = SectionsFileParser(tempfile.mkstemp()[1])
+			fileDescriptor, path = tempfile.mkstemp()
+			writeSectionsFileParser = SectionsFileParser(path)
 			writeSectionsFileParser.sections = readSectionsFileParser.sections
 			writeSectionsFileParser.comments = readSectionsFileParser.comments
 			writeSectionsFileParser.write()
 
-			checkingSectionsFileParser = SectionsFileParser(writeSectionsFileParser.file)
+			checkingSectionsFileParser = SectionsFileParser(writeSectionsFileParser.path)
 			checkingSectionsFileParser.read() and checkingSectionsFileParser.parse(stripComments=False,
 																			rawSections=STANDARD_FILES_RAW_SECTIONS[type])
 			self.assertDictEqual(readSectionsFileParser.sections, checkingSectionsFileParser.sections)
-			os.remove(writeSectionsFileParser.file)
+			os.close(fileDescriptor)
 
 		# Standard sections files with namespaces.
 		for type, file in STANDARD_FILES.iteritems():
@@ -628,30 +631,32 @@ class SectionsFileParserTestCase(unittest.TestCase):
 																			stripComments=False,
 																			rawSections=STANDARD_FILES_RAW_SECTIONS[type])
 
-			writeSectionsFileParser = SectionsFileParser(tempfile.mkstemp()[1])
+			fileDescriptor, path = tempfile.mkstemp()
+			writeSectionsFileParser = SectionsFileParser(path)
 			writeSectionsFileParser.sections = readSectionsFileParser.sections
 			writeSectionsFileParser.comments = readSectionsFileParser.comments
 			writeSectionsFileParser.write(namespaces=True)
 
-			checkingSectionsFileParser = SectionsFileParser(writeSectionsFileParser.file)
+			checkingSectionsFileParser = SectionsFileParser(writeSectionsFileParser.path)
 			checkingSectionsFileParser.read() and checkingSectionsFileParser.parse(namespaces=False,
 																			stripComments=False,
 																			rawSections=STANDARD_FILES_RAW_SECTIONS[type])
 			self.assertDictEqual(readSectionsFileParser.sections, checkingSectionsFileParser.sections)
-			os.remove(writeSectionsFileParser.file)
+			os.close(fileDescriptor)
 
 		# Default section file.
 		readSectionsFileParser = SectionsFileParser(DEFAULTS_FILE)
 		readSectionsFileParser.read() and readSectionsFileParser.parse()
 
-		writeSectionsFileParser = SectionsFileParser(tempfile.mkstemp()[1])
+		fileDescriptor, path = tempfile.mkstemp()
+		writeSectionsFileParser = SectionsFileParser(path)
 		writeSectionsFileParser.sections = readSectionsFileParser.sections
 		writeSectionsFileParser.comments = readSectionsFileParser.comments
 		writeSectionsFileParser.write()
 
-		checkingSectionsFileParser = SectionsFileParser(writeSectionsFileParser.file)
+		checkingSectionsFileParser = SectionsFileParser(writeSectionsFileParser.path)
 		checkingSectionsFileParser.read() and checkingSectionsFileParser.parse()
-		os.remove(writeSectionsFileParser.file)
+		os.remove(writeSectionsFileParser.path)
 
 class PlistFileParserTestCase(unittest.TestCase):
 	"""
@@ -663,11 +668,11 @@ class PlistFileParserTestCase(unittest.TestCase):
 		This method tests presence of required attributes.
 		"""
 
-		requiredAttributes = ("file",
-								"content",
-								"elements",
-								"parsingErrors",
-								"unserializers")
+		requiredAttributes = ("path",
+							"content",
+							"elements",
+							"parsingErrors",
+							"unserializers")
 
 		for attribute in requiredAttributes:
 			self.assertIn(attribute, dir(PlistFileParser))
@@ -678,9 +683,9 @@ class PlistFileParserTestCase(unittest.TestCase):
 		"""
 
 		requiredMethods = ("parse",
-							"elementExists",
-							"filterValues",
-							"getValue")
+						"elementExists",
+						"filterValues",
+						"getValue")
 
 		for method in requiredMethods:
 			self.assertIn(method, dir(PlistFileParser))
